@@ -26,7 +26,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -46,7 +48,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -99,7 +103,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -119,7 +125,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -172,7 +180,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -192,7 +202,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -245,7 +257,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -265,7 +279,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -318,7 +334,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -338,7 +356,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -391,7 +411,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -411,7 +433,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -464,7 +488,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -484,7 +510,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -537,7 +565,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -557,7 +587,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -610,7 +642,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -630,7 +664,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -683,7 +719,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -703,7 +741,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
